Inactivating a pass
Date: 06 23, 2001 10:26:59 AM

# Inactivating Passes

To inactivate a pass in the analyzer sequence:

1. Select the pass in the Ana Tab.

2. Right-click and select, Properties.

3. In the Pass Properties dialog, uncheck the Active box. The current pass number is indicated in the From: To: windows.

4. Click OK to finish inactivating the pass. The pass will show a break in the chain, indicating that it has been inactivated.

Note: You can also inactivate other passes in the sequence at the same time. Check the To End box to indicate all passes from the current pass forward should be skipped. Check All to indicate ALL passes in the analyzer sequence should be skipped.